==> masons-java-sdk-1.0.2-sources.jar: ai/mrs/connection/utils/HTTPUtil.java <==
package ai.mrs.connection.utils;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Map;

public class HTTPUtil {
    private static String dispatchRequest(String method, String urlStr, String body, Map<String, String> headers) {
        String result = null;
        HttpURLConnection connection = null;
        InputStreamReader in = null;
        try {
            // local pc host: 10.0.2.2
            URL url = new URL(urlStr);
            connection = (HttpURLConnection) url.openConnection();
            connection.setDoInput(true);
            connection.setDoOutput(true);
            connection.setRequestMethod(method);
            connection.setRequestProperty("Content-Type", "application/json");
            connection.setRequestProperty("Charset", "utf-8");
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                connection.setRequestProperty(entry.getKey(), entry.getValue());
            }
            DataOutputStream dop = new DataOutputStream(connection.getOutputStream());
            dop.writeBytes(body);
            dop.flush();
            dop.close();

            in = new InputStreamReader(connection.getInputStream());
            BufferedReader bufferedReader = new BufferedReader(in);
            StringBuffer strBuffer = new StringBuffer();
            String line;
            while ((line = bufferedReader.readLine()) != null) {
                strBuffer.append(line);
            }
            result = strBuffer.toString();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

        }
        return result;
    }

    public static String post(String url, String body, Map<String, String> headers) {
        return HTTPUtil.dispatchRequest("POST", url, body, headers);
    }
}

==> masons-java-sdk-1.2.2-sources.jar: ai/mrs/connection/utils/HTTPUtil.java <==
package ai.mrs.connection.utils;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.Proxy;
import java.net.URL;
import java.util.Map;

public class HTTPUtil {
    private static String dispatchRequest(
            String method, String urlStr,
            String body, Map<String, String> headers,
            Proxy proxy
    ) {
        String result = null;
        HttpURLConnection connection = null;
        InputStreamReader in = null;
        try {
            // local pc host: 10.0.2.2
            URL url = new URL(urlStr);
            if (null != proxy) {
                connection = (HttpURLConnection) url.openConnection(proxy);
            } else {
                connection = (HttpURLConnection) url.openConnection();
            }
            connection.setDoInput(true);
            connection.setDoOutput(true);
            connection.setRequestMethod(method);
            connection.setRequestProperty("Content-Type", "application/json");
            connection.setRequestProperty("Charset", "utf-8");
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                connection.setRequestProperty(entry.getKey(), entry.getValue());
            }
            DataOutputStream dop = new DataOutputStream(connection.getOutputStream());
            dop.writeBytes(body);
            dop.flush();
            dop.close();

            in = new InputStreamReader(connection.getInputStream());
            BufferedReader bufferedReader = new BufferedReader(in);
            StringBuffer strBuffer = new StringBuffer();
            String line;
            while ((line = bufferedReader.readLine()) != null) {
                strBuffer.append(line);
            }
            result = strBuffer.toString();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

        }
        return result;
    }

    public static String post(String url, String body, Map<String, String> headers, Proxy proxy) {
        return HTTPUtil.dispatchRequest("POST", url, body, headers, proxy);
    }
}
